==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPolyDataPointPlacer.java <==
// java wrapper for vtkPolyDataPointPlacer object
//

package vtk;
import vtk.*;

public class vtkPolyDataPointPlacer extends vtkPointPlacer
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddProp_2(vtkProp id0);
  public void AddProp(vtkProp id0)
    { AddProp_2(id0); }

  private native void RemoveViewProp_3(vtkProp id0);
  public void RemoveViewProp(vtkProp id0)
    { RemoveViewProp_3(id0); }

  private native void RemoveAllProps_4();
  public void RemoveAllProps()
    { RemoveAllProps_4(); }

  private native int HasProp_5(vtkProp id0);
  public int HasProp(vtkProp id0)
    { return HasProp_5(id0); }

  private native int GetNumberOfProps_6();
  public int GetNumberOfProps()
    { return GetNumberOfProps_6(); }

  private native int ComputeWorldPosition_7(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_7(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_8(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_8(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_9(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_9(id0); }

  private native int ValidateDisplayPosition_10(vtkRenderer id0,double id1[]);
  public int ValidateDisplayPosition(vtkRenderer id0,double id1[])
    { return ValidateDisplayPosition_10(id0,id1); }

  private native int ValidateWorldPosition_11(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_11(id0,id1); }

  private native long GetPropPicker_12();
  public vtkPropPicker GetPropPicker() {
    long temp = GetPropPicker_12();

    if (temp == 0) return null;
    return (vtkPropPicker)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkPolyDataPointPlacer() { super(); }

  public vtkPolyDataPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkPolyDataPointPlacer.java <==
// java wrapper for vtkPolyDataPointPlacer object
//

package vtk;
import vtk.*;

public class vtkPolyDataPointPlacer extends vtkPointPlacer
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddProp_2(vtkProp id0);
  public void AddProp(vtkProp id0)
    { AddProp_2(id0); }

  private native void RemoveViewProp_3(vtkProp id0);
  public void RemoveViewProp(vtkProp id0)
    { RemoveViewProp_3(id0); }

  private native void RemoveAllProps_4();
  public void RemoveAllProps()
    { RemoveAllProps_4(); }

  private native int HasProp_5(vtkProp id0);
  public int HasProp(vtkProp id0)
    { return HasProp_5(id0); }

  private native int GetNumberOfProps_6();
  public int GetNumberOfProps()
    { return GetNumberOfProps_6(); }

  private native int ComputeWorldPosition_7(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_7(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_8(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_8(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_9(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_9(id0); }

  private native int ValidateDisplayPosition_10(vtkRenderer id0,double id1[]);
  public int ValidateDisplayPosition(vtkRenderer id0,double id1[])
    { return ValidateDisplayPosition_10(id0,id1); }

  private native int ValidateWorldPosition_11(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_11(id0,id1); }

  private native long GetPropPicker_12();
  public vtkPropPicker GetPropPicker() {
    long temp = GetPropPicker_12();

    if (temp == 0) return null;
    return (vtkPropPicker)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPolyDataPointPlacer() { super(); }

  public vtkPolyDataPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}
